<?php

namespace Drupal\cass_cookies_test\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\cas_server\Ticket\TicketFactory;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Provide testing access to the internal unique id.
 */
class UniqueId implements ContainerInjectionInterface {

  /**
   * The ticket factory.
   *
   * @var \Drupal\cas_server\Ticket\TicketFactory
   */
  protected $ticketFactory;

  /**
   * Creates a new UniqueId object.
   *
   * @phpcs:disable Drupal.Functions.MultiLineFunctionDeclaration.MissingTrailingComma
   */
  public function __construct(
    TicketFactory $ticket_factory
  ) {
    // phpcs:enable
    $this->ticketFactory = $ticket_factory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('cas_server.ticket_factory')
    );
  }

  /**
   * Show the user's internal unique identifier in machine consumable format.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The unique id as an array encoded in a JSON string.
   */
  public function show() {
    $unique_id = $this->ticketFactory->getUniqueId(FALSE);

    return new Response(
      Json::encode(['unique_id' => $unique_id]),
      Response::HTTP_OK,
      ['content-type' => 'text/json']
    );
  }

}
